pub enum JitError {
Setup(String),
Compilation(String),
UnsupportedOpcode(String),
Translation(String),
FunctionNotFound(String),
TypeError(String),
}Expand description
Errors produced by the JIT compiler.
Variants
Setup(String)
Cranelift ISA or settings configuration failed.
Compilation(String)
Cranelift compilation or module error.
UnsupportedOpcode(String)
An opcode or bytecode construct is not supported by the JIT.
Translation(String)
Translation from bytecode to Cranelift IR failed.
FunctionNotFound(String)
A function referenced by the bytecode was not found.
TypeError(String)
Type error during JIT compilation.