take_jit_runtime_error

Function take_jit_runtime_error 

pub fn take_jit_runtime_error() -> Option<String>
Take (and clear) the recorded VM-trampoline error message. Called by JITExecutor when a JIT-compiled function returns a negative signal, so the clean VM error can be surfaced in place of a generic JIT error code.