jit_v2_array_set_decimal

Function jit_v2_array_set_decimal 

#[unsafe(no_mangle)]
pub extern "C" fn jit_v2_array_set_decimal( arr: *mut TypedArray<*const DecimalObj>, index: i64, val: *const u8, )
Write a per-element heap pointer at index in a TypedArray<*const DecimalObj>. The caller must have an owning refcount share for val and is responsible for releasing any previous element at index before this call.