pub fn preflight_jit_compatibility(
program: &BytecodeProgram,
) -> JitPreflightReportExpand description
Run JIT preflight and collect all constructs that require VM fallback.
pub fn preflight_jit_compatibility(
program: &BytecodeProgram,
) -> JitPreflightReportRun JIT preflight and collect all constructs that require VM fallback.