pub struct InductionVar {
pub local_slot: u16,
pub is_module_binding: bool,
pub bound_cmp: IntCC,
pub bound_slot: Option<u16>,
pub step_value: Option<i64>,
}Expand description
An induction variable: a local or module binding that follows the pattern
var = var + step each iteration.
Fields
local_slot: u16The local variable slot used as induction variable
is_module_binding: boolWhether this is a module binding (true) or local variable (false)
bound_cmp: IntCCComparison condition used in loop test
bound_slot: Option<u16>The local slot that the induction var is compared against (bound)
step_value: Option<i64>The constant step value (e.g. 1 for i = i + 1), if detected