Module mixed_table

Module mixed_table 

Mixed function table supporting both JIT-compiled and interpreter-fallback entries.

When per-blob JIT preflight determines that some functions cannot be JIT-compiled (e.g. they use async opcodes or unsupported builtins), we still want to JIT-compile the functions that can be compiled. The MixedFunctionTable maps each function to either a native code pointer or a marker indicating VM interpretation.

Structs

MixedFunctionTable
Mixed function table mapping function IDs to either native or interpreted entries.

Enums

FunctionEntry
Entry in the mixed function table supporting both JIT and interpreted functions.