Object FFI Functions for JIT
This module provides FFI functions for creating and manipulating objects, arrays, closures, and performing property access operations in the JIT.
Modules
object_ops- Object creation, manipulation, and metadata operationsproperty_access- Property access for objects, arrays, strings, series, and other typesconversion- Conversion between NaN-boxed bits and runtime Valuesformat- String formatting with template substitutionclosure- Closure creation with captured valuespattern- Pattern matching helpers for Result/Option types
Re-exports
pub use object_ops::jit_new_object;pub use object_ops::jit_object_rest;pub use object_ops::jit_set_prop;pub use property_access::jit_get_prop;pub use property_access::jit_hashmap_shape_id;pub use property_access::jit_hashmap_value_at;pub use property_access::jit_length;pub use conversion::jit_bits_to_nanboxed;pub use conversion::jit_bits_to_nanboxed_with_ctx;pub use conversion::jit_bits_to_typed_scalar;pub use conversion::nanboxed_to_jit_bits;pub use conversion::typed_scalar_to_jit_bits;pub use format::jit_format;pub use closure::jit_make_closure;pub use pattern::jit_pattern_check_constructor;pub use pattern::jit_pattern_extract_constructor;
Modules
- closure
- Closure Creation
- conversion
- Conversion Between NaN-Boxed Bits and Runtime Values / ValueWord
- format
- String Formatting Utilities
- object_
ops - Object Creation and Manipulation Operations
- pattern
- Pattern Matching Helpers
- property_
access - Property Access Operations